@@ -20,6 +20,7 @@ from tempest.lib import decorators
 from tempest.lib import exceptions as lib_exc
 from testtools import testcase as tc
 
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests import utils
 
@@ -72,7 +73,7 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
     @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     @ddt.data('2.0', '2.6', '2.7', '2.40', '2.41')
     def test_share_type_create_get(self, version):
-        self.skip_if_microversion_not_supported(version)
+        utils.check_skip_if_microversion_not_supported(version)
 
         name = data_utils.rand_name("tempest-manila")
         description = None
@@ -84,24 +85,32 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         st_create = self.create_share_type(
             name, extra_specs=extra_specs, version=version,
             description=description)
-        self.assertEqual(name, st_create['share_type']['name'])
+        self.assertEqual(name, st_create['name'])
         self._verify_description(
-            description, st_create['share_type'], version)
-        self._verify_is_public_key_name(st_create['share_type'], version)
-        st_id = st_create["share_type"]["id"]
+            description, st_create, version)
+        self._verify_is_public_key_name(st_create, version)
+        st_id = st_create["id"]
 
         # Get share type
         get = self.shares_v2_client.get_share_type(st_id, version=version)
+
         self.assertEqual(name, get["share_type"]["name"])
         self.assertEqual(st_id, get["share_type"]["id"])
         self._verify_description(description, get['share_type'], version)
+
+        if utils.is_microversion_lt(version, "2.24"):
+            # snapshot_support is an implied/required extra-spec until
+            # version 2.24, and the service assumes it to be True since we
+            # don't provide it during share type creation.
+            extra_specs.update({"snapshot_support": 'True'})
+
         self.assertEqual(extra_specs, get["share_type"]["extra_specs"])
         self._verify_is_public_key_name(get['share_type'], version)
 
         # Check that backwards compatibility didn't break
         self.assertDictMatch(get["volume_type"], get["share_type"])
 
-    @base.skip_if_microversion_lt("2.50")
+    @utils.skip_if_microversion_not_supported("2.50")
     @decorators.idempotent_id('a9af19e1-e789-4c4f-a39b-dd8df6ed00b1')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     @ddt.data(
@@ -130,11 +139,11 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         st_create = self.create_share_type(
             name, extra_specs=extra_specs, version=version,
             description=description)
-        self.assertEqual(name, st_create['share_type']['name'])
+        self.assertEqual(name, st_create['name'])
         self._verify_description(
-            description, st_create['share_type'], version)
-        self._verify_is_public_key_name(st_create['share_type'], version)
-        st_id = st_create["share_type"]["id"]
+            description, st_create, version)
+        self._verify_is_public_key_name(st_create, version)
+        st_id = st_create["id"]
 
         # Update share type
         updated_st = self.shares_v2_client.update_share_type(
@@ -150,7 +159,7 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
                 st_is_public,
                 updated_st["share_type"]["share_type_access:is_public"])
 
-    @base.skip_if_microversion_lt("2.50")
+    @utils.skip_if_microversion_not_supported("2.50")
     @decorators.idempotent_id('9019dc61-b2b1-472d-9b15-a3986439d4c3')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     @ddt.data(
@@ -168,11 +177,11 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         st_create = self.create_share_type(
             name, extra_specs=extra_specs, version=version,
             description=description)
-        self.assertEqual(name, st_create['share_type']['name'])
+        self.assertEqual(name, st_create['name'])
         self._verify_description(
-            description, st_create['share_type'], version)
-        self._verify_is_public_key_name(st_create['share_type'], version)
-        st_id = st_create["share_type"]["id"]
+            description, st_create, version)
+        self._verify_is_public_key_name(st_create, version)
+        st_id = st_create["id"]
 
         # Update share type
         updated_st = self.shares_v2_client.update_share_type(
@@ -185,7 +194,7 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
     @tc.attr(base.TAG_POSITIVE, base.TAG_API)
     @ddt.data('2.0', '2.6', '2.7', '2.40', '2.41')
     def test_share_type_create_list(self, version):
-        self.skip_if_microversion_not_supported(version)
+        utils.check_skip_if_microversion_not_supported(version)
 
         name = data_utils.rand_name("tempest-manila")
         description = None
@@ -197,8 +206,8 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         st_create = self.create_share_type(
             name, extra_specs=extra_specs, version=version,
             description=description)
-        self._verify_is_public_key_name(st_create['share_type'], version)
-        st_id = st_create["share_type"]["id"]
+        self._verify_is_public_key_name(st_create, version)
+        st_id = st_create["id"]
 
         # list share types
         st_list = self.shares_v2_client.list_share_types(version=version)
@@ -231,18 +240,21 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
 
         # Create share with share type
         share = self.create_share(
-            name=share_name, share_type_id=st_create["share_type"]["id"])
+            name=share_name, share_type_id=st_create["id"])
         self.assertEqual(share["name"], share_name)
-        self.shares_client.wait_for_share_status(share["id"], "available")
+        waiters.wait_for_resource_status(
+            self.shares_client, share["id"], "available")
 
         # Verify share info
-        get = self.shares_v2_client.get_share(share["id"], version="2.5")
+        get = self.shares_v2_client.get_share(
+            share["id"], version="2.5")['share']
         self.assertEqual(share_name, get["name"])
         self.assertEqual(share["id"], get["id"])
         self.assertEqual(shr_type_name, get["share_type"])
 
-        get = self.shares_v2_client.get_share(share["id"], version="2.6")
-        self.assertEqual(st_create["share_type"]["id"], get["share_type"])
+        get = self.shares_v2_client.get_share(
+            share["id"], version="2.6")['share']
+        self.assertEqual(st_create["id"], get["share_type"])
         self.assertEqual(shr_type_name, get["share_type_name"])
 
     @decorators.idempotent_id('d2261a27-d4a4-4237-9fad-f6fd8f27783a')
@@ -255,8 +267,8 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         # Create private share type
         st_create = self.create_share_type(
             name, False, extra_specs=extra_specs)
-        self.assertEqual(name, st_create['share_type']['name'])
-        st_id = st_create["share_type"]["id"]
+        self.assertEqual(name, st_create['name'])
+        st_id = st_create["id"]
 
         # It should not be listed without access
         st_list = self.shares_v2_client.list_share_types()
@@ -264,7 +276,8 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         self.assertFalse(any(st_id in st["id"] for st in sts))
 
         # List projects that have access for share type - none expected
-        access = self.shares_v2_client.list_access_to_share_type(st_id)
+        access = self.shares_v2_client.list_access_to_share_type(
+            st_id)['share_type_access']
         self.assertEmpty(access)
 
         # Add project access to share type
@@ -277,7 +290,8 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         self.assertTrue(any(st_id in st["id"] for st in sts))
 
         # List projects that have access for share type - one expected
-        access = self.shares_v2_client.list_access_to_share_type(st_id)
+        access = self.shares_v2_client.list_access_to_share_type(
+            st_id)['share_type_access']
         expected = [{'share_type_id': st_id, 'project_id': project_id}, ]
         self.assertEqual(expected, access)
 
@@ -291,20 +305,21 @@ class ShareTypesAdminTest(base.BaseSharesAdminTest):
         self.assertFalse(any(st_id in st["id"] for st in sts))
 
         # List projects that have access for share type - none expected
-        access = self.shares_v2_client.list_access_to_share_type(st_id)
+        access = self.shares_v2_client.list_access_to_share_type(
+            st_id)['share_type_access']
         self.assertEmpty(access)
 
     @decorators.idempotent_id('90dca5c5-f28e-4f16-90ed-78f5d725664e')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API)
-    @ddt.data(*set(('2.45', '2.46', LATEST_MICROVERSION)))
+    @ddt.data(*utils.deduplicate(('2.45', '2.46', LATEST_MICROVERSION)))
     def test_share_type_create_show_list_with_is_default_key(self, version):
-        self.skip_if_microversion_not_supported(version)
+        utils.check_skip_if_microversion_not_supported(version)
         name = data_utils.rand_name("tempest-manila")
         extra_specs = self.add_extra_specs_to_dict()
 
         # Create share type
         st_create = self.create_share_type(
-            name, extra_specs=extra_specs, version=version)['share_type']
+            name, extra_specs=extra_specs, version=version)
 
         if utils.is_microversion_ge(version, '2.46'):
             self.assertIn('is_default', st_create)
